# Climbing
This package creates a few python classes that describe rock-climbing.  It was created as an exercise in package development.

# Quickstart
It is available to install using pip:

`pip install pgs_climbing`

And can then be used by importing into your python files:

`from pgs_climbing import Crag, Route, Climber, GRADES_LIST`

# Source
This package is held on [Github](https://github.com/paul-stubley/Climbing).  For a full README, see the link.

# Contents
The classes are currently:

- Crag - A class to hold information about each climbing area, the routes it contains and its location.
- Route - A class to hold information about a particular route - its name, grade, height etc.
- Climber - A class to hold information about a climber, the routes they have attempted/climbed and when.


